pub struct String<const L: usize>(_);
A non-zero sized inlined String. It doesn’t keep any length, the assumption is
that the capacity is always utilised.
Constructs a String<L> from an at most L bytes-long string slice,
left-padding if the slice is less than L bytes-long.
let s = "three";
let string = String::<9>::try_from_str_padded(s).unwrap();
assert_eq!(string, "three ");
let string_err = String::<3>::try_from_str_padded(s);
assert!(string_err.is_err());
Constructs a String<L> from at most L bytes.
left-padding if the number of bytes is less than L.
let bytes = b"three";
let string = String::<9>::try_from_bytes_padded(bytes).unwrap();
assert_eq!(string.as_bytes(), b"three ");
Turns the String into its underlying bytes.
Returns whether all bytes in the String are empty.
Returns whether the first byte of the String is empty.
Can be used as a faster version of is_empty.
Performs copy-assignment from source. Read more
Formats the value using the given formatter. Read more
Returns the “default value” for a type. Read more
The resulting type after dereferencing.
Mutably dereferences the value.
The returned type after indexing.
Performs the indexing (container[index]) operation. Read more
The returned type after indexing.
Performs the indexing (container[index]) operation. Read more
The returned type after indexing.
Performs the indexing (container[index]) operation. Read more
The returned type after indexing.
Performs the indexing (container[index]) operation. Read more
The returned type after indexing.
Performs the indexing (container[index]) operation. Read more
The returned type after indexing.
Performs the indexing (container[index]) operation. Read more
Performs the mutable indexing (container[index]) operation. Read more
Performs the mutable indexing (container[index]) operation. Read more
Performs the mutable indexing (container[index]) operation. Read more
Performs the mutable indexing (container[index]) operation. Read more
Performs the mutable indexing (container[index]) operation. Read more
Performs the mutable indexing (container[index]) operation. Read more
Compares and returns the maximum of two values. Read more
Compares and returns the minimum of two values. Read more
Restrict a value to a certain interval. Read more
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.
This method returns an ordering between self and other values if one exists. Read more
This method tests less than (for self and other) and is used by the < operator. Read more
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
This method tests greater than (for self and other) and is used by the > operator. Read more
This method tests greater than or equal to (for self and other) and is used by the >=
operator. Read more
The type returned in the event of a conversion error.
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning. Read more
🔬 This is a nightly-only experimental API. (toowned_clone_into)
recently added
Uses borrowed data to replace owned data, usually by cloning. Read more
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.